"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.print = exports.tokenizeAsync = exports.tokenize = void 0;
const prism = require("prismjs");
const prismutils = require("./prismutils");
const printTree_1 = require("tree-dump/lib/printTree");
const aliases_1 = require("./aliases");
const collectChildren = (children, tokens) => {
    const length = children.length;
    for (let i = 0; i < length; i++) {
        const child = children[i];
        if (typeof child === 'string') {
            const len = child.length;
            tokens.push(len);
        }
        else if (child instanceof prism.Token) {
            const token = [[child.type], []];
            const alias = child.alias;
            if (alias) {
                if (typeof child.alias === 'string')
                    token[0].push(child.alias);
                else if (alias instanceof Array)
                    token[0].push(...child.alias);
            }
            tokens.push(token);
            let content = child.content;
            if (content === 'string') {
                const len = content.length;
                token[1][0] = len;
            }
            else {
                if (!(content instanceof Array))
                    content = [content];
                collectChildren(content, token[1]);
            }
        }
    }
};
const tokenize = (code, lang) => {
    lang = lang.toLowerCase();
    const grammar = prism.languages[lang] ?? prism.languages[(lang = 'clike')];
    const children = prism.tokenize(code, grammar);
    const token = [['language-' + lang], []];
    collectChildren(children, token[1]);
    return token;
};
exports.tokenize = tokenize;
const tokenizeAsync = async (code, lang) => {
    lang = lang.toLowerCase();
    let langs = [lang];
    if (!prismutils.hasLang(lang) && aliases_1.aliases[lang])
        langs = aliases_1.aliases[lang] instanceof Array ? aliases_1.aliases[lang] : [aliases_1.aliases[lang]];
    lang = langs[langs.length - 1];
    for (const l of langs) {
        if (!prismutils.hasLang(l)) {
            try {
                await prismutils.loadLang(l);
            }
            catch (error) {
                console.log('Failed to load language:', l);
                console.error(error);
            }
        }
    }
    return (0, exports.tokenize)(code, lang);
};
exports.tokenizeAsync = tokenizeAsync;
const printToken0 = (tab, str, token, offset) => {
    if (typeof token === 'number')
        return ['(' + offset + ',' + token + '): ' + JSON.stringify(str.slice(offset, offset + token)), offset + token];
    const [type, children] = token;
    return [
        type.join(', ') +
            (0, printTree_1.printTree)(tab, children.map((child) => (tab) => {
                const p = printToken0(tab, str, child, offset);
                offset = p[1];
                return p[0];
            })),
        offset,
    ];
};
const print = (str, token) => printToken0('', str, token, 0)[0];
exports.print = print;
//# sourceMappingURL=tokenize.js.map